==> igniteui-react-core-16.16.1.tgz: package/esm2015/lib/FontDefaults.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, markType } from "./type";
import { BrushUtil } from "./BrushUtil";
import { DeviceUtils } from "./DeviceUtils";
/**
 * @hidden
 */
export let FontDefaults = /*@__PURE__*/ (() => {
    class FontDefaults extends Base {
        static aq(a) {
            return "Titillium Web, " + a + ", Arial, sans-serif";
        }
    }
    FontDefaults.$t = /*@__PURE__*/ markType(FontDefaults, 'FontDefaults');
    FontDefaults.legendLabelsBrush = /*@__PURE__*/ BrushUtil.g(255, 37, 37, 37);
    FontDefaults.legendLabelsFontSizeConst = 13;
    FontDefaults.legendLabelsFontSize = /*@__PURE__*/ DeviceUtils.f(13);
    FontDefaults.legendLabelsFontConst = "Verdana";
    FontDefaults.legendLabelsFontFamily = /*@__PURE__*/ FontDefaults.aq("Verdana");
    FontDefaults.dataLegendFontBrush = /*@__PURE__*/ BrushUtil.g(255, 37, 37, 37);
    FontDefaults.dataLegendFontSizeConst = 13;
    FontDefaults.dataLegendFontSize = /*@__PURE__*/ DeviceUtils.f(13);
    FontDefaults.dataLegendFontFamilyConst = "Verdana";
    FontDefaults.dataLegendFontFamily = /*@__PURE__*/ FontDefaults.aq("Verdana");
    FontDefaults.dataLegendFontWeight = "400";
    FontDefaults.dataLegendFontStyle = "Normal";
    FontDefaults.dataLegendFontStretch = "Normal";
    FontDefaults.dataLegendFontVariant = "Normal";
    FontDefaults.dataLegendHeaderFontWeight = "600";
    FontDefaults.chartAxisLabelBrush = /*@__PURE__*/ BrushUtil.g(255, 78, 78, 78);
    FontDefaults.chartFontSizeConst = 13;
    FontDefaults.chartFontSize = /*@__PURE__*/ DeviceUtils.f(13);
    FontDefaults.chartFontNameConst = "Verdana";
    FontDefaults.chartFontFamily = /*@__PURE__*/ FontDefaults.aq("Verdana");
    FontDefaults.chartFontWeight = "400";
    FontDefaults.chartFontStyle = "Normal";
    FontDefaults.chartFontStretch = "Normal";
    FontDefaults.chartFontVariant = "Normal";
    FontDefaults.chartTitleFontSizeConst = 20;
    FontDefaults.chartTitleFontSize = /*@__PURE__*/ DeviceUtils.f(20);
    FontDefaults.chartTitleNameConst = "Verdana";
    FontDefaults.chartTitleFontWeight = "600";
    FontDefaults.chartSubtitleFontSizeConst = 20;
    FontDefaults.chartSubtitleFontSize = /*@__PURE__*/ DeviceUtils.f(20);
    FontDefaults.chartSubtitleNameConst = "Verdana";
    FontDefaults.chartSubtitleFontWeight = "600";
    FontDefaults.tooltipLabelsBrush = /*@__PURE__*/ BrushUtil.g(255, 78, 78, 78);
    FontDefaults.tooltipLabelsFontSizeConst = 13;
    FontDefaults.tooltipLabelsFontSize = /*@__PURE__*/ DeviceUtils.f(FontDefaults.tooltipLabelsFontSizeConst);
    FontDefaults.tooltipFontNameConst = "Verdana";
    FontDefaults.tooltipLabelsFontFamily = /*@__PURE__*/ FontDefaults.aq("Verdana");
    FontDefaults.gaugesFontBrush = /*@__PURE__*/ BrushUtil.g(255, 97, 97, 97);
    FontDefaults.gaugesFontSizeConst = 12;
    FontDefaults.gaugesFontSize = /*@__PURE__*/ DeviceUtils.f(12);
    FontDefaults.gaugesFontFamilyConst = "Verdana";
    FontDefaults.gaugesFontWeight = "600";
    FontDefaults.gaugesFontFamily = /*@__PURE__*/ FontDefaults.aq("Verdana");
    FontDefaults.treemapFontSizeConst = 13;
    FontDefaults.treemapFontSize = /*@__PURE__*/ DeviceUtils.f(13);
    FontDefaults.treemapHeaderFontSizeConst = 13;
    FontDefaults.treemapHeaderFontSize = /*@__PURE__*/ DeviceUtils.f(13);
    FontDefaults.treemapFontFamilyConst = "Verdana";
    FontDefaults.treemapFontFamily = /*@__PURE__*/ FontDefaults.aq("Verdana");
    FontDefaults.treemapHeaderFontFamily = /*@__PURE__*/ FontDefaults.aq("Verdana");
    FontDefaults.zoomSliderFontSizeConst = 10;
    FontDefaults.zoomSliderFontSize = /*@__PURE__*/ DeviceUtils.f(10);
    FontDefaults.zoomSliderNameConst = "Verdana";
    return FontDefaults;
})();

==> igniteui-react-core-18.5.1.tgz: package/esm2015/lib/FontDefaults.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, markType } from "./type";
import { BrushUtil } from "./BrushUtil";
import { DeviceUtils } from "./DeviceUtils";
/**
 * @hidden
 */
export let FontDefaults = /*@__PURE__*/ (() => {
    class FontDefaults extends Base {
        static ay(a) {
            return "Titillium Web, " + a + ", Arial, sans-serif";
        }
    }
    FontDefaults.$t = /*@__PURE__*/ markType(FontDefaults, 'FontDefaults');
    FontDefaults.legendLabelsBrush = /*@__PURE__*/ BrushUtil.h(255, 37, 37, 37);
    FontDefaults.legendLabelsFontSizeConst = 13;
    FontDefaults.legendLabelsFontSize = /*@__PURE__*/ DeviceUtils.f(13);
    FontDefaults.legendLabelsFontConst = "Verdana";
    FontDefaults.legendLabelsFontFamily = /*@__PURE__*/ FontDefaults.ay("Verdana");
    FontDefaults.dataLegendFontBrush = /*@__PURE__*/ BrushUtil.h(255, 37, 37, 37);
    FontDefaults.dataLegendFontSizeConst = 13;
    FontDefaults.dataLegendFontSize = /*@__PURE__*/ DeviceUtils.f(13);
    FontDefaults.dataLegendFontFamilyConst = "Verdana";
    FontDefaults.dataLegendFontFamily = /*@__PURE__*/ FontDefaults.ay("Verdana");
    FontDefaults.dataLegendFontWeight = "400";
    FontDefaults.dataLegendFontStyle = "Normal";
    FontDefaults.dataLegendFontStretch = "Normal";
    FontDefaults.dataLegendFontVariant = "Normal";
    FontDefaults.dataLegendHeaderFontWeight = "600";
    FontDefaults.chartAxisLabelBrush = /*@__PURE__*/ BrushUtil.h(255, 78, 78, 78);
    FontDefaults.chartFontSizeConst = 13;
    FontDefaults.chartFontSize = /*@__PURE__*/ DeviceUtils.f(13);
    FontDefaults.chartFontNameConst = "Verdana";
    FontDefaults.chartXAxisLabelsMarginTop = 5;
    FontDefaults.chartXAxisLabelsMarginBottom = 5;
    FontDefaults.chartXAxisLabelsMarginLeft = 2;
    FontDefaults.chartXAxisLabelsMarginRight = 2;
    FontDefaults.chartYAxisLabelsMarginTop = 2;
    FontDefaults.chartYAxisLabelsMarginBottom = 2;
    FontDefaults.chartYAxisLabelsMarginLeft = 5;
    FontDefaults.chartYAxisLabelsMarginRight = 5;
    FontDefaults.chartFontFamily = /*@__PURE__*/ FontDefaults.ay("Verdana");
    FontDefaults.chartFontWeight = "400";
    FontDefaults.chartFontStyle = "Normal";
    FontDefaults.chartFontStretch = "Normal";
    FontDefaults.chartFontVariant = "Normal";
    FontDefaults.chartTitleFontSizeConst = 20;
    FontDefaults.chartTitleFontSize = /*@__PURE__*/ DeviceUtils.f(20);
    FontDefaults.chartTitleNameConst = "Verdana";
    FontDefaults.chartTitleFontWeight = "600";
    FontDefaults.chartSubtitleFontSizeConst = 20;
    FontDefaults.chartSubtitleFontSize = /*@__PURE__*/ DeviceUtils.f(20);
    FontDefaults.chartSubtitleNameConst = "Verdana";
    FontDefaults.chartSubtitleFontWeight = "600";
    FontDefaults.tooltipLabelsBrush = /*@__PURE__*/ BrushUtil.h(255, 78, 78, 78);
    FontDefaults.tooltipLabelsFontSizeConst = 13;
    FontDefaults.tooltipLabelsFontSize = /*@__PURE__*/ DeviceUtils.f(FontDefaults.tooltipLabelsFontSizeConst);
    FontDefaults.tooltipFontNameConst = "Verdana";
    FontDefaults.tooltipLabelsFontFamily = /*@__PURE__*/ FontDefaults.ay("Verdana");
    FontDefaults.gaugesFontBrush = /*@__PURE__*/ BrushUtil.h(255, 97, 97, 97);
    FontDefaults.gaugesFontSizeConst = 12;
    FontDefaults.gaugesFontSize = /*@__PURE__*/ DeviceUtils.f(12);
    FontDefaults.gaugesFontFamilyConst = "Verdana";
    FontDefaults.gaugesFontWeight = "600";
    FontDefaults.gaugesFontFamily = /*@__PURE__*/ FontDefaults.ay("Verdana");
    FontDefaults.treemapFontSizeConst = 13;
    FontDefaults.treemapFontSize = /*@__PURE__*/ DeviceUtils.f(13);
    FontDefaults.treemapHeaderFontSizeConst = 13;
    FontDefaults.treemapHeaderFontSize = /*@__PURE__*/ DeviceUtils.f(13);
    FontDefaults.treemapFontFamilyConst = "Verdana";
    FontDefaults.treemapFontFamily = /*@__PURE__*/ FontDefaults.ay("Verdana");
    FontDefaults.treemapHeaderFontFamily = /*@__PURE__*/ FontDefaults.ay("Verdana");
    FontDefaults.zoomSliderFontSizeConst = 10;
    FontDefaults.zoomSliderFontSize = /*@__PURE__*/ DeviceUtils.f(10);
    FontDefaults.zoomSliderNameConst = "Verdana";
    return FontDefaults;
})();
